It is not called from outside h264.c
---
 libavcodec/h264.c |    8 ++++----
 libavcodec/h264.h |    1 -
 2 files changed, 4 insertions(+), 5 deletions(-)

diff --git a/libavcodec/h264.h b/libavcodec/h264.h
index e33f37e..3482d89 100644
--- a/libavcodec/h264.h
+++ b/libavcodec/h264.h
@@ -709,7 +709,6 @@ int ff_h264_check_intra4x4_pred_mode(H264Context *h);
 int ff_h264_check_intra_pred_mode(H264Context *h, int mode, int is_chroma);
 
 void ff_h264_hl_decode_mb(H264Context *h);
-int ff_h264_frame_start(H264Context *h);
 int ff_h264_decode_extradata(H264Context *h);
 int ff_h264_decode_init(AVCodecContext *avctx);
 void ff_h264_decode_init_vlc(void);
diff --git a/libavcodec/h264.c b/libavcodec/h264.c
index 472fa47..f6099b1 100644
--- a/libavcodec/h264.c
+++ b/libavcodec/h264.c
@@ -1589,7 +1589,7 @@ static int decode_update_thread_context(AVCodecContext 
*dst,
         context_reinitialized = 1;
 
         /* update linesize on resize. The decoder doesn't
          * necessarily call ff_h264_frame_start in the new thread */
         h->linesize   = h1->linesize;
         h->uvlinesize = h1->uvlinesize;
 
@@ -1732,7 +1732,7 @@ static int decode_update_thread_context(AVCodecContext 
*dst,
     return err;
 }
 
-int ff_h264_frame_start(H264Context *h)
+static int h264_frame_start(H264Context *h)
 {
     Picture *pic;
     int i, ret;
@@ -3371,7 +3371,7 @@ static int decode_slice_header(H264Context *h, 
H264Context *h0)
             Picture *prev = h->short_ref_count ? h->short_ref[0] : NULL;
             av_log(h->avctx, AV_LOG_DEBUG, "Frame num gap %d %d\n",
                    h->frame_num, h->prev_frame_num);
-            if (ff_h264_frame_start(h) < 0)
+            if (h264_frame_start(h) < 0)
                 return -1;
             h->prev_frame_num++;
             h->prev_frame_num %= 1 << h->sps.log2_max_frame_num;
@@ -3433,7 +3433,7 @@ static int decode_slice_header(H264Context *h, 
H264Context *h0)
         }
 
         if (!FIELD_PICTURE || h0->first_field) {
-            if (ff_h264_frame_start(h) < 0) {
+            if (h264_frame_start(h) < 0) {
                 h0->first_field = 0;
                 return -1;
             }
@@ -1589,7 +1589,7 @@ static int decode_update_thread_context(AVCodecContext 
 
         /* update linesize on resize. The decoder doesn't
-         * necessarily call ff_h264_frame_start in the new thread */
+         * necessarily call h264_frame_start in the new thread */
         h->linesize   = h1->linesize;
         h->uvlinesize = h1->uvlinesize;
-- 
1.7.10.4

_______________________________________________
libav-devel mailing list
[email protected]
https://lists.libav.org/mailman/listinfo/libav-devel

Reply via email to